==> img0ch-2.1.11.zip: img0ch/_template/zeromin2/plugin_load.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu.cs" ?>

<?cs include:"zeromin2/plugin_right_menu.cs" ?>

<div id="main">

<form id="pluginContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">プラグイン管理</a>
</div>

<h1>プラグイン管理</h1>

<?cs if:Code0 ?>
<?cs if:Done_plugin_save ?><div class="noticeSuccess" id="notify"><p><?cs var:html_escape(Enabled) ?>個のプラグインを有効に、<?cs var:html_escape(Disabled) ?>個のプラグインを無効にしました</p></div><?cs /if ?>
<?cs if:Done_plugin_install ?><div class="noticeSuccess" id="notify"><p><?cs var:html_escape(Found) ?>個のプラグインを新規追加しました</p></div><?cs /if ?>
<?cs if:Done_plugin_uninstall ?><div class="noticeSuccess" id="notify"><p><?cs var:html_escape(Found) ?>個のプラグインを削除しました</p></div><?cs /if ?>
<?cs if:Done_plugin_load ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<p>
  <dl>
    <dt>*プラグインの有効無効の設定</dt>
    <dd>チェックされたプラグインを有効に、されないプラグインを無効にします</dd>
    <dt>*プラグインのインストール(新規プラグイン検索)</dt>
    <dd>プラグインのディレクトリから新しいプラグインを検索します</dd>
    <dt>*プラグインのアンインストール</dt>
    <dd>プラグインのアンインストールを行います(但し定義されている場合のみ)</dd>
  </dl>
</p>

<p>
<select name="method">
  <option value="load">プラグインの一覧を表示</option>
  <option value="save">プラグインの有効無効の設定</option>
  <option value="install">プラグインのインストール</option>
  <option value="uninstall">プラグインのアンインストール</option>
</select><br />
<select name="query" onchange="jQuery('form#pluginContainerForm').get(0).submit()">
<option value="">全てのプラグインを表示する</option>
<?cs each:item = PluginClasses ?><option value="<?cs var:item.name ?>"><?cs var:item.name ?></option>
<?cs /each ?>
</select>
<input type="submit" value="実行" />
</p>

<p>
ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>
</p>

<table class="simple">
  <thead>
  <tr>
    <th><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'id' )" /></th>
    <th>クラス名</th>
    <th>メソッド名</th>
    <th>呼出箇所</th>
  </tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
  <tr>
    <td><input type="checkbox" name="id" value="<?cs var:html_escape(item.id) ?>" <?cs if:item.enabled ?>checked="checked"<?cs /if ?>/></td>
    <td><?cs var:html_escape(item.class) ?></td>
    <td><?cs var:html_escape(item.method) ?></td>
    <td><?cs var:html_escape(item.type) ?></td>
  </tr>
  <?cs /each ?>
  </tbody>
</table>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="plugin" />
<?cs each:item = Entries ?><input type="hidden" name="plugin" value="<?cs var:html_escape(item.id) ?>" />
<?cs /each ?>
<input type="hidden" name="OK" value="load" />
<input type="hidden" name="NG" value="load" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-2.1.16.zip: img0ch/_template/zeromin2/plugin_load.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu.cs" ?>

<?cs include:"zeromin2/plugin_right_menu.cs" ?>

<div id="main">

<form id="pluginContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">プラグイン管理</a>
</div>

<h1>プラグイン管理</h1>

<?cs if:Code0 ?>
<?cs if:Done_plugin_save ?><div class="noticeSuccess" id="notify"><p><?cs var:html_escape(Enabled) ?>個のプラグインを有効に、<?cs var:html_escape(Disabled) ?>個のプラグインを無効にしました</p></div><?cs /if ?>
<?cs if:Done_plugin_install ?><div class="noticeSuccess" id="notify"><p><?cs var:html_escape(Found) ?>個のプラグインを新規追加しました</p></div><?cs /if ?>
<?cs if:Done_plugin_uninstall ?><div class="noticeSuccess" id="notify"><p><?cs var:html_escape(Found) ?>個のプラグインを削除しました</p></div><?cs /if ?>
<?cs if:Done_plugin_load ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<p>
  <dl>
    <dt>*プラグインの有効無効の設定</dt>
    <dd>チェックされたプラグインを有効に、されないプラグインを無効にします</dd>
    <dt>*プラグインのインストール(新規プラグイン検索)</dt>
    <dd>プラグインのディレクトリから新しいプラグインを検索します</dd>
    <dt>*プラグインのアンインストール</dt>
    <dd>プラグインのアンインストールを行います(但し定義されている場合のみ)</dd>
  </dl>
</p>

<p>
<select name="method">
  <option value="load">プラグインの一覧を表示</option>
  <option value="save">プラグインの有効無効の設定</option>
  <option value="install">プラグインのインストール</option>
  <option value="uninstall">プラグインのアンインストール</option>
</select><br />
<select name="query" onchange="jQuery('form#pluginContainerForm').get(0).submit()">
<option value="">全てのプラグインを表示する</option>
<?cs each:item = PluginClasses ?><option value="<?cs var:item.name ?>"><?cs var:item.name ?></option>
<?cs /each ?>
</select>
<input type="submit" value="実行" />
</p>

<p>
ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>
</p>

<table class="simple">
  <thead>
  <tr>
    <th><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'id' )" /></th>
    <th>クラス名</th>
    <th>メソッド名</th>
    <th>呼出箇所</th>
  </tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
  <tr>
    <td><input type="checkbox" name="id" value="<?cs var:html_escape(item.id) ?>" <?cs if:item.enabled ?>checked="checked"<?cs /if ?>/></td>
    <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load_config&amp;id=<?cs var:html_escape(item.id) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.class) ?></a></td>
    <td><?cs var:html_escape(item.method) ?></td>
    <td><?cs var:html_escape(item.type) ?></td>
  </tr>
  <?cs /each ?>
  </tbody>
</table>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="plugin" />
<?cs each:item = Entries ?><input type="hidden" name="plugin" value="<?cs var:html_escape(item.id) ?>" />
<?cs /each ?>
<input type="hidden" name="OK" value="load" />
<input type="hidden" name="NG" value="load" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
